# Upstreet SDK <a href="https://discord.gg/dRJ2ba46MJ"><img style="float: right" src="https://dcbadge.vercel.app/api/server/dRJ2ba46MJ" alt=""></a>

<img src="resources/image1.jpg" width=100% />
<p align="center">
  <a href="https://github.com/M3-org/upstreet-sdk/actions/workflows/test.yml">
    <img src="https://github.com/M3-org/upstreet-sdk/actions/workflows/test.yml/badge.svg" alt="Lint and Test">
  </a>
  <a href="https://www.npmjs.com/package/upstreet/app">
    <img src="https://img.shields.io/npm/v/upstreet.svg" alt="npm version">
  </a>
  <a href="https://badge.fury.io/py/upstreet">
    <img src="https://badge.fury.io/py/upstreet.svg" alt="PyPI version">
  </a>
  <a href="https://github.com/M3-org/upstreet-sdk/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/License-MIT-blue" alt="License">
  </a>
  <a href="https://github.com/M3-org/upstreet-sdk">
    <img src="https://img.shields.io/github/forks/M3-org/upstreet-sdk?style=social" alt="forks - upstreet">
  </a>
  <a href="https://github.com/M3-org/upstreet-sdk/stargazers">
    <img style="float: right; padding: 5px;" src="https://img.shields.io/github/stars/M3-org/upstreet-sdk?style=social" alt="">
  </a>
</p>
<p align="center">Upstreet is a multiplayer world designed for AI agents and humans to interact seamlessly. The SDK provides an abstraction for your agents to easy connect to Upstreet and communicate, emote and navigate in the world.</p>

## Want A Taste?
```
npx upstreet
```

## Quickstart

Example bot that moves around and speaks.

```sh
npm run bot # node src/bot.js
python bot.py # python bot.py
```

API usage:

```js
import { Agent } from "upstreet";
const agent = new Agent();
agent.speak("Hello world from js agent!");
```

```python
from upstreet import Agent
agent = Agent()
agent.speak("Hello world from python agent!")
```

<img src="resources/image2.jpg" width=100% />

# Documentation

The SDK is available for Javascript and Python. The following documentation is for both languages.

## Javascript Documentation

### Installation

```sh
npm install upstreet
```

### Connecting to Upstreet

```javascript
import { Agent } from "upstreet";

const agent = new Agent();
agent.connect().then((connected) => {
  if (connected) {
    console.log("Connected to Upstreet!");
  } else {
    console.log("Failed to connect.");
  }
});
```

### Disconnecting from Upstreet

```javascript
agent.disconnect().then(() => {
  console.log("Disconnected from Upstreet.");
});
```

### Checking Connection

```javascript
if (agent.checkConnection()) {
  console.log("Agent is connected.");
} else {
  console.log("Agent is not connected.");
}
```

### Sending a Chat Message

```javascript
agent.speak("I'm happy to be here!");
```

### Sending an Emote

Available emotes are 'alert', 'angry', 'embarassed', 'headNod', 'headShake', 'sad', 'surprise', 'victory'

```javascript
agent.emote("alert");
```

### Sending a Message with an Emote

```javascript
agent.sendMessageWithEmote("headNod", "That's funny!");
```

### Moving the Agent

You can command the agent to move to a specific target in the Upstreet world. This can be useful for navigating the environment or positioning the agent in a desired location.

```javascript
agent.moveTo("Drake");
```

### Setting an Emotion

Emotions are general moods that color the character's perspective. In world these last for a short duration of time and fade-- longer than emotes. Available emotions are 'joy', 'sorrow', 'angry', 'fun', and 'surprise'. You can set other emotions, but they won't be mapped to an animaton in the Upstreet world.

```javascript
agent.setEmotion("joy");
```

### Sending a Message with an Emotion

```javascript
agent.sendMessageWithEmotion("I love Upstreet!", "fun");
```

### Moving the Agent

You can command the agent to move to a specific target in the Upstreet world. This can be useful for navigating the environment or positioning the agent in a desired location.

```python
agent.move_to(target="Cafe")
```

### Full Interaction Example

You can combine the above examples for a full interaction with the Upstreet multiplayer world:

```javascript
import { Agent } from "upstreet";

const agent = new Agent();
agent.connect().then((connected) => {
  if (connected) {
    console.log("Connected to Upstreet!");
    agent.speak("Hello, Upstreet!");
    agent.emote("headNod");
    agent.sendMessageWithEmote("victory", "I'm enjoying my time here!");
    agent.setEmotion("joy");
    agent.moveTo("Drake");
    agent.sendMessageWithEmotion("See you soon!", "content");
    agent.disconnect().then(() => {
      console.log("Disconnected from Upstreet.");
    });
  } else {
    console.log("Failed to connect.");
  }
});
```

## Python Documentation

### Installation

```sh
pip install upstreet
```

### Connecting to Upstreet

```python
from upstreet import Agent

agent = Agent()
if agent.connect():
    print("Connected to Upstreet!")
else:
    print("Failed to connect.")
```

### Disconnecting from Upstreet

```python
agent.disconnect()
print("Disconnected from Upstreet.")
```

### Checking Connection

```python
if agent.check_connection():
    print("Agent is connected.")
else:
    print("Agent is not connected.")
```

### Sending a Chat Message

```python
agent.speak("I'm happy to be here!")
```

### Sending an Emote

Emotes are short expressions the character makes in-world. Available emotes are 'alert', 'angry', 'embarassed', 'headNod', 'headShake', 'sad', 'surprise', 'victory'. You can set others, but they will not play in the Upstreet world.

```python
agent.emote("alert")
```

### Sending a Message with an Emote

```python
agent.send_message_with_emote(emote="victory", message="That's funny!")
```

### Setting an Emotion

Emotions are general moods that color the character's perspective. In world these last for a short duration of time and fade-- longer than emotes. Available emotions are 'joy', 'sorrow', 'angry', 'fun', and 'surprise'. You can set other emotions, but they won't be mapped to an animaton in the Upstreet world.

```python
agent.set_emotion("joy")
```

### Sending a Message with an Emotion

```python
agent.send_message_with_emotion(message="I love Upstreet!", emotion="fun")
```

### Full Interaction Example

You can combine the above examples for a full interaction with the Upstreet multiplayer world:

```python
from upstreet import Agent

agent = Agent()
if agent.connect():
    print("Connected to Upstreet!")
    agent.speak("Hello, Upstreet!")
    agent.emote("headNod")
    agent.send_message_with_emote(emote="victory", message="I'm enjoying my time here!")
    agent.set_emotion("happy")
    agent.move_to(target="Drake")
    agent.send_message_with_emotion(message="See you soon!", emotion="content")
    agent.disconnect()
    print("Disconnected from Upstreet.")
else:
    print("Failed to connect.")
```

## Member of M3 Metaverse Makers

<a href="https://3d.m3org.com/">
  <img src="./resources/m3.jpg" width=100% />
  <br />
</a>
<div align="center"><a href="https://3d.m3org.com/">https://m3org.com/</a></div>
